@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -47,7 +47,7 @@ public class ReCaptchaServlet extends DataServlet {
 
     // -----------------------------------------------------------------------------------------------------
 
-    private final ServiceLookup services;
+    private transient final ServiceLookup services;
 
     /**
      * Initializes a new {@link ReCaptchaServlet}.
